# Generated by roxygen2: do not edit by hand

S3method(plot,Extrema)
S3method(plot,Lines)
S3method(plot,Lines3D)
S3method(plot,NumArcs)
S3method(plot,PCDs)
S3method(plot,Patterns)
S3method(plot,Planes)
S3method(plot,TriLines)
S3method(plot,Uniform)
S3method(print,Extrema)
S3method(print,Lines)
S3method(print,Lines3D)
S3method(print,NumArcs)
S3method(print,PCDs)
S3method(print,Patterns)
S3method(print,Planes)
S3method(print,TriLines)
S3method(print,Uniform)
S3method(print,summary.Extrema)
S3method(print,summary.Lines)
S3method(print,summary.Lines3D)
S3method(print,summary.NumArcs)
S3method(print,summary.PCDs)
S3method(print,summary.Patterns)
S3method(print,summary.Planes)
S3method(print,summary.TriLines)
S3method(print,summary.Uniform)
S3method(summary,Extrema)
S3method(summary,Lines)
S3method(summary,Lines3D)
S3method(summary,NumArcs)
S3method(summary,PCDs)
S3method(summary,Patterns)
S3method(summary,Planes)
S3method(summary,TriLines)
S3method(summary,Uniform)
export(ASarc.dens.tri)
export(CSarc.dens.test)
export(CSarc.dens.test.int)
export(CSarc.dens.test1D)
export(CSarc.dens.tri)
export(Dist)
export(IarcASbasic.tri)
export(IarcASset2pnt.tri)
export(IarcAStri)
export(IarcCSbasic.tri)
export(IarcCSedge.reg.std.tri)
export(IarcCSend.int)
export(IarcCSint)
export(IarcCSmid.int)
export(IarcCSset2pnt.std.tri)
export(IarcCSset2pnt.tri)
export(IarcCSstd.tri)
export(IarcCSstd.triRAB)
export(IarcCSstd.triRAC)
export(IarcCSstd.triRBC)
export(IarcCSt1.std.tri)
export(IarcCSt1.std.triRAB)
export(IarcCSt1.std.triRAC)
export(IarcCSt1.std.triRBC)
export(IarcCStri)
export(IarcCStri.alt)
export(IarcPEbasic.tri)
export(IarcPEend.int)
export(IarcPEint)
export(IarcPEmid.int)
export(IarcPEset2pnt.std.tri)
export(IarcPEset2pnt.tri)
export(IarcPEstd.tetra)
export(IarcPEstd.tri)
export(IarcPEtetra)
export(IarcPEtri)
export(Idom.num.up.bnd)
export(Idom.num1ASbasic.tri)
export(Idom.num1AStri)
export(Idom.num1CSint)
export(Idom.num1CSstd.tri)
export(Idom.num1CSt1std.tri)
export(Idom.num1PEbasic.tri)
export(Idom.num1PEint)
export(Idom.num1PEstd.tetra)
export(Idom.num1PEtetra)
export(Idom.num1PEtri)
export(Idom.num2ASbasic.tri)
export(Idom.num2AStri)
export(Idom.num2CSstd.tri)
export(Idom.num2PEbasic.tri)
export(Idom.num2PEstd.tetra)
export(Idom.num2PEtetra)
export(Idom.num2PEtri)
export(Idom.num3CSstd.tri)
export(Idom.num3PEstd.tetra)
export(Idom.num3PEtetra)
export(Idom.num4CSstd.tri)
export(Idom.num5CSstd.tri)
export(Idom.num6CSstd.tri)
export(Idom.numASup.bnd.tri)
export(Idom.numCSup.bnd.std.tri)
export(Idom.numCSup.bnd.tri)
export(Idom.setAStri)
export(Idom.setCSstd.tri)
export(Idom.setCStri)
export(Idom.setPEstd.tri)
export(Idom.setPEtri)
export(Line)
export(Line3D)
export(NASbasic.tri)
export(NAStri)
export(NCSint)
export(NCStri)
export(NPEbasic.tri)
export(NPEint)
export(NPEstd.tetra)
export(NPEtetra)
export(NPEtri)
export(PEarc.dens.test)
export(PEarc.dens.test.int)
export(PEarc.dens.test1D)
export(PEarc.dens.tetra)
export(PEarc.dens.tri)
export(PEdom.num)
export(PEdom.num.binom.test)
export(PEdom.num.binom.test1D)
export(PEdom.num.binom.test1Dint)
export(PEdom.num.nondeg)
export(PEdom.num.norm.test)
export(PEdom.num.tetra)
export(PEdom.num.tri)
export(PEdom.num1D)
export(PEdom.num1Dnondeg)
export(Pdom.num2PE1D)
export(Pdom.num2PE1Dasy)
export(Pdom.num2PEtri)
export(Plane)
export(Xin.convex.hullY)
export(angle.str2end)
export(angle3pnts)
export(arcsAS)
export(arcsAStri)
export(arcsCS)
export(arcsCS1D)
export(arcsCSend.int)
export(arcsCSint)
export(arcsCSmid.int)
export(arcsCStri)
export(arcsPE)
export(arcsPE1D)
export(arcsPEend.int)
export(arcsPEint)
export(arcsPEmid.int)
export(arcsPEtri)
export(area.polygon)
export(as.basic.tri)
export(asy.varCS1D)
export(asy.varCS2D)
export(asy.varCSend.int)
export(asy.varPE1D)
export(asy.varPE2D)
export(asy.varPEend.int)
export(bary2cart)
export(cart2bary)
export(center.nondegPE)
export(centerMc)
export(centersMc)
export(circumcenter.basic.tri)
export(circumcenter.tetra)
export(circumcenter.tri)
export(cl2CCvert.reg)
export(cl2CCvert.reg.basic.tri)
export(cl2Mc.int)
export(cl2edges.std.tri)
export(cl2edges.vert.reg.basic.tri)
export(cl2edgesCCvert.reg)
export(cl2edgesCMvert.reg)
export(cl2edgesMvert.reg)
export(cl2faces.vert.reg.tetra)
export(dimension)
export(dist.point2line)
export(dist.point2plane)
export(dist.point2set)
export(dom.num.exact)
export(dom.num.greedy)
export(edge.reg.triCM)
export(fr2edgesCMedge.reg.std.tri)
export(fr2vertsCCvert.reg)
export(fr2vertsCCvert.reg.basic.tri)
export(in.circle)
export(in.tetrahedron)
export(in.tri.all)
export(in.triangle)
export(inci.matAS)
export(inci.matAStri)
export(inci.matCS)
export(inci.matCS1D)
export(inci.matCSint)
export(inci.matCSstd.tri)
export(inci.matCStri)
export(inci.matPE)
export(inci.matPE1D)
export(inci.matPEint)
export(inci.matPEstd.tri)
export(inci.matPEtetra)
export(inci.matPEtri)
export(index.delaunay.tri)
export(index.six.Te)
export(indices.delaunay.tri)
export(intersect.line.circle)
export(intersect.line.plane)
export(intersect2lines)
export(interval.indices.set)
export(is.in.data)
export(is.point)
export(is.std.eq.tri)
export(kfr2vertsCCvert.reg)
export(kfr2vertsCCvert.reg.basic.tri)
export(lineA2CMinTe)
export(lineA2MinTe)
export(lineB2CMinTe)
export(lineB2MinTe)
export(lineC2MinTe)
export(lineD1CCinTb)
export(lineD2CCinTb)
export(muCS1D)
export(muCS2D)
export(muCSend.int)
export(muPE1D)
export(muPE2D)
export(muPEend.int)
export(num.arcsAS)
export(num.arcsAStri)
export(num.arcsCS)
export(num.arcsCS1D)
export(num.arcsCSend.int)
export(num.arcsCSint)
export(num.arcsCSmid.int)
export(num.arcsCSstd.tri)
export(num.arcsCStri)
export(num.arcsPE)
export(num.arcsPE1D)
export(num.arcsPEend.int)
export(num.arcsPEint)
export(num.arcsPEmid.int)
export(num.arcsPEstd.tri)
export(num.arcsPEtetra)
export(num.arcsPEtri)
export(num.delaunay.tri)
export(order.dist2edges.std.tri)
export(paraline)
export(paraline3D)
export(paraplane)
export(perpline)
export(perpline2plane)
export(plotASarcs)
export(plotASarcs.tri)
export(plotASregs)
export(plotASregs.tri)
export(plotCSarcs)
export(plotCSarcs.int)
export(plotCSarcs.tri)
export(plotCSarcs1D)
export(plotCSregs)
export(plotCSregs.int)
export(plotCSregs.tri)
export(plotCSregs1D)
export(plotDelaunay.tri)
export(plotIntervals)
export(plotPEarcs)
export(plotPEarcs.int)
export(plotPEarcs.tri)
export(plotPEarcs1D)
export(plotPEregs)
export(plotPEregs.int)
export(plotPEregs.std.tetra)
export(plotPEregs.tetra)
export(plotPEregs.tri)
export(plotPEregs1D)
export(prj.cent2edges)
export(prj.cent2edges.basic.tri)
export(prj.nondegPEcent2edges)
export(radii)
export(radius)
export(rank.dist2edges.std.tri)
export(rassoc.circular)
export(rassoc.matern)
export(rassoc.multi.tri)
export(rassoc.std.tri)
export(rassoc.tri)
export(rassocII.std.tri)
export(rel.edge.basic.tri)
export(rel.edge.basic.triCM)
export(rel.edge.std.triCM)
export(rel.edge.tri)
export(rel.edge.triCM)
export(rel.edges.tri)
export(rel.edges.triCM)
export(rel.vert.basic.tri)
export(rel.vert.basic.triCC)
export(rel.vert.basic.triCM)
export(rel.vert.end.int)
export(rel.vert.mid.int)
export(rel.vert.std.tri)
export(rel.vert.std.triCM)
export(rel.vert.tetraCC)
export(rel.vert.tetraCM)
export(rel.vert.tri)
export(rel.vert.triCC)
export(rel.vert.triCM)
export(rel.verts.tri)
export(rel.verts.tri.nondegPE)
export(rel.verts.triCC)
export(rel.verts.triCM)
export(rel.verts.triM)
export(rseg.circular)
export(rseg.multi.tri)
export(rseg.std.tri)
export(rseg.tri)
export(rsegII.std.tri)
export(runif.basic.tri)
export(runif.multi.tri)
export(runif.std.tetra)
export(runif.std.tri)
export(runif.std.tri.onesixth)
export(runif.tetra)
export(runif.tri)
export(seg.tri.support)
export(six.extremaTe)
export(slope)
export(tri2std.basic.tri)
import(graphics)
import(interp)
import(plot3D)
import(stats)
importFrom(Rdpack,reprompt)
