
This is an R package that contains the functions for construction and visualization of proximity catch digraphs (PCDs) for one, two and three dimensional data. The PCD families considered are Arc-Slice (AS) PCDs, Proportional-Edge (PE) PCDs and Central Similarity (CS) PCDs. The package also contains functions for testing spatial patterns of segregation and association against complete spatial randomness (CSR) and Uniformness in one and two dimensional cases. Also included are the functions for generating points from these spatial patterns.

Install from GitHub :  devtools::install_github("elvanceyhan/pcds")
